@@ -282,7 +282,7 @@ void MainWindow::savethemedone()
     } else {
         ThemeWin->hide();
         saveasnew = "1";
-        runscript();
+        runscript("0");
     }
 }
 
@@ -313,12 +313,12 @@ void MainWindow::on_pushButton_clicked()
 
             } else {
                 saveasnew.clear();
-                runscript();
+                runscript("0");
             }
 
 }
 
-void MainWindow::runscript()
+void MainWindow::runscript(QString command)
 {
     QString varattu;
     varattu = "Theme Customizer";
@@ -345,6 +345,31 @@ void MainWindow::runscript()
 
     }
 
+    if ( command == "saveonly" ) {
+        progress.setValue(10);
+        progress.setValue(15);
+        progress.setValue(20);
+        progress.setValue(25);
+        readdirs();
+        progress.setValue(30);
+        progress.setValue(35);
+        oldfonts("/etc/hildon/theme/colors.config");
+        progress.setValue(40);
+        progress.setValue(45);
+        progress.setValue(50);
+        readSettings();
+        progress.setValue(55);
+        progress.setValue(60);
+        progress.setValue(70);
+        readgtkrc();
+        progress.setValue(80);
+        progress.setValue(90);
+        progress.cancel();
+        QMaemo5InformationBox::information(this, tr("New theme saved!"), QMaemo5InformationBox::DefaultTimeout);
+        return;
+
+    }
+
 //        QMaemo5InformationBox::information(this, tr("Creating backups..."), 1);
     progress.setLabelText(tr("Creating backups..."));
 //        sleep(2);
@@ -718,7 +743,7 @@ void MainWindow::on_about_triggered()
     msgBox.setWindowTitle(tr("About Theme Customizer"));
     msgBox.setText("Author: D-Iivil - Licence: Freeware & open source");
     msgBox.setTextFormat(Qt::RichText);
-    msgBox.setInformativeText("<html>Version: 0.9-26<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
+    msgBox.setInformativeText("<html>Version: 0.9-32<br /><a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_donations&business=ricky%40hevikaraoke%2efi&lc=FI&item_name=Here%27s%20some%20money%20for%20beer%2e&no_note=0&currency_code=EUR&bn=PP%2dDonationsBF%3abtn_donate_SM%2egif%3aNonHostedGuest\">Be a nice guy and <b>donate some money for beer</b> to author</a></html>");
     msgBox.setStandardButtons(QMessageBox::Ok);
     msgBox.setDefaultButton(QMessageBox::Ok);
     msgBox.button(msgBox.Ok)->setText(tr("Ok, thanks."));
@@ -935,3 +960,36 @@ void MainWindow::process2Finished2(int)
     system("sleep 2 && killall hildon-desktop");
     system("killall theme-customizer");
 }
+
+void MainWindow::on_actionSave_as_new_theme_triggered()
+{
+    ThemeWin = new savenewtheme(this);
+    connect(ThemeWin->ui->Save, SIGNAL(clicked()), this, SLOT(savetheme()));
+    ThemeWin->show();
+}
+
+void MainWindow::savetheme()
+{
+    themename = ThemeWin->ui->FileName->text();
+    themedir = themename;
+    themedir = themedir.remove(QChar('\"'));
+    themedir = themedir.remove(QChar(' '));
+    themedir = themedir.simplified();
+    themedir = themedir.toLower();
+    QDir file;
+    file = "/opt/usr/share/themes/" + themedir;
+
+    if (themename.isEmpty()) {
+
+        QMaemo5InformationBox::information(this, tr("You must give name for the theme."), QMaemo5InformationBox::DefaultTimeout);
+
+    } else if (file.exists()) {
+
+        QMaemo5InformationBox::information(this, tr("Folder ") + themedir + tr(" already exists!"), QMaemo5InformationBox::DefaultTimeout);
+
+    } else {
+        ThemeWin->hide();
+        saveasnew = "1";
+        runscript("saveonly");
+    }
+}
