@@ -53,6 +53,7 @@ private:
     void readSettings();
     void writeSettings();
     void SetOpacity(QString imagefile, int opacity);
+    void runscript(QString command);
     QString f1;
     QString f2;
     QString f3;
@@ -73,6 +74,7 @@ private:
     savenewtheme* ThemeWin;
 
 private slots:
+    void on_actionSave_as_new_theme_triggered();
     void on_Opacity_top_editingFinished();
     void on_horizontalSlider_5_valueChanged(int value);
     void on_actionRestore_theme_files_triggered();
@@ -81,7 +83,7 @@ private slots:
     void on_pushButton_4_clicked();
     void savedone();
     void savethemedone();
-    void runscript();
+    void savetheme();
     void on_pushButton_3_clicked();
     void on_actionChange_backgrounds_triggered();
     void on_horizontalSlider_4_valueChanged(int value);
